## syntax for EFA analysis of flow data and construction of scree plot and histograms for supp material

####EFA analysis, requires file "Flow Data EFA.sav"

#Loads relevant packages
library(EFA.dimensions) 
library(foreign)     # to read .sav spss files

# define a read.sav function 
read.sav <- function(...) {read.spss( ..., to.data.frame=TRUE) }

#to read in datafile, user will need to edit the file directly where the file is saved
data_FLOW <- read.sav("C:/Users/jc195117/OneDrive - James Cook University/Research/Active Projects/Flow Scale/Flow Data EFA.sav", header = TRUE)

#for KMO and Bartlet's test
FACTORABILITY(data_FLOW)

#to run tests, NEVALSGTI was excluded as only relevant to data in correlation matrix format
DIMTESTS(data_FLOW, tests = c("CD", "EMPKC", "HULL", "MAP", "RAWPAR", "SALIENT", "SESCREE", "SMT"))

#produces a basic scree plot
SCREE_PLOT(data_FLOW)

#runs the factor analysis
PA_FA(data_FLOW, Nfactors = 4, rotate = "PROMAX", verbose=TRUE)

#cites package
citation("EFA.dimensions")

####Construct scree plot in supp material

library(ggplot2) 
library(EFA.dimensions)

RAWPAR(data_FLOW)

#take the RAWPAR output table and save this as a datafile which you can then import into R (e.g., I saved this as an excel file)

#imported data in file called Parallel_Analysis_Data.xlxs
ggplot(data = Parallel_Analysis_Data, aes(x = Root))+
  
  #adds observed Eigenvalues to plot
  geom_line(aes(y = Real, color = "Observed Values"), size = .5)+
  geom_point(aes(y = Real, color = "Observed Values"), size = 1, shape = 16)+
  
  #adds parallel Eigenvalues to plot
  geom_line(aes(y = Percentile, color = "95th Percentile Values"), size = .5)+
  geom_point(aes(y = Percentile, color = "95th Percentile Values"), shape = 18, size = 1)+
  
  #adds a horizontal line at Y = 1
  geom_hline(yintercept = 1, size = .5, colour="#000000", linetype = 2)+
  
  #adjusts breaks to improve visualisation
  scale_x_continuous(breaks = seq(1, 28, 1))+
  scale_y_continuous(breaks = seq(0, 10, 1))+
  
  #adds labels to the axes
  labs(y = "Eigenvalue", x = "Factor Number") +
  
  
  theme_classic()+
  
  ##to get the legend; guide is to force the legend to include geom point shapes
  scale_color_manual(values=c("Observed Values"="#0072B2", "95th Percentile Values"="#FF9999"),
                     guide = guide_legend(override.aes = list(shape = c(16, 18))))+
  
  #moves the legend and removes the unnesecary legend title
  theme(legend.position = c(.8,.9))+
  theme(legend.title = element_blank())

####Histograms for Supp Material, requires "Flow Data All Participants for Correlations.sav"
library(foreign)     # to read .sav spss files
library(ggplot2) 

# define a read.sav function 
read.sav <- function(...) {read.spss( ..., to.data.frame=TRUE) }

#to read in datafile,user will need to edit the file directly where the file is saved
HISTO_DATA <- read.sav("C:/Users/jc195117/OneDrive - James Cook University/Research/Active Projects/Flow Scale/Flow Data All Participants for Correlations.sav", header = TRUE)

intensity_plot <- ggplot(HISTO_DATA, aes(x=HISTO_DATA$Intensity)) + 
  geom_histogram(binwidth=1, fill="#0072B2", color="#e9ecef")+
  scale_x_continuous(limits = c(1, 10), breaks = seq(1, 10, 1))+
  labs(y = "Frequency", x = "Reported Intensity of Flow (from 1-10)")+
  theme_classic()

duration_plot <- ggplot(HISTO_DATA, aes(x=HISTO_DATA$Duration)) + 
  geom_histogram(binwidth=1, fill="#FF9999", color="#e9ecef")+
  scale_x_continuous(limits = c(1, 100), breaks = seq(0, 100, 5))+
  labs(y = "Frequency", x = "Percentage of Time in Flow")+
  theme_classic()